@@ -220,7 +220,7 @@ class SQLExecuteQueryOperator(BaseSQLOperator):
         :ref:`howto/operator:SQLExecuteQueryOperator`
     """
 
-    template_fields: Sequence[str] = ("conn_id", "sql", "parameters")
+    template_fields: Sequence[str] = ("conn_id", "sql", "parameters", "hook_params")
     template_ext: Sequence[str] = (".sql", ".json")
     template_fields_renderers = {"sql": "sql", "parameters": "json"}
     ui_color = "#cdaaed"
@@ -416,7 +416,7 @@ class SQLColumnCheckOperator(BaseSQLOperator):
         :ref:`howto/operator:SQLColumnCheckOperator`
     """
 
-    template_fields: Sequence[str] = ("partition_clause", "table", "sql")
+    template_fields: Sequence[str] = ("partition_clause", "table", "sql", "hook_params")
     template_fields_renderers = {"sql": "sql"}
 
     sql_check_template = """
@@ -644,7 +644,7 @@ class SQLTableCheckOperator(BaseSQLOperator):
         :ref:`howto/operator:SQLTableCheckOperator`
     """
 
-    template_fields: Sequence[str] = ("partition_clause", "table", "sql", "conn_id")
+    template_fields: Sequence[str] = ("partition_clause", "table", "sql", "conn_id", "hook_params")
 
     template_fields_renderers = {"sql": "sql"}
 
@@ -760,7 +760,7 @@ class SQLCheckOperator(BaseSQLOperator):
     :param parameters: (optional) the parameters to render the SQL query with.
     """
 
-    template_fields: Sequence[str] = ("sql",)
+    template_fields: Sequence[str] = ("sql", "hook_params")
     template_ext: Sequence[str] = (
         ".hql",
         ".sql",
@@ -809,6 +809,7 @@ class SQLValueCheckOperator(BaseSQLOperator):
     template_fields: Sequence[str] = (
         "sql",
         "pass_value",
+        "hook_params",
     )
     template_ext: Sequence[str] = (
         ".hql",
@@ -906,7 +907,7 @@ class SQLIntervalCheckOperator(BaseSQLOperator):
     """
 
     __mapper_args__ = {"polymorphic_identity": "SQLIntervalCheckOperator"}
-    template_fields: Sequence[str] = ("sql1", "sql2")
+    template_fields: Sequence[str] = ("sql1", "sql2", "hook_params")
     template_ext: Sequence[str] = (
         ".hql",
         ".sql",
@@ -1034,7 +1035,7 @@ class SQLThresholdCheckOperator(BaseSQLOperator):
     :param max_threshold: numerical value or max threshold sql to be executed (templated)
     """
 
-    template_fields: Sequence[str] = ("sql", "min_threshold", "max_threshold")
+    template_fields: Sequence[str] = ("sql", "min_threshold", "max_threshold", "hook_params")
     template_ext: Sequence[str] = (
         ".hql",
         ".sql",
